﻿#region Copyright
/// <summary>The ScummVM WPF UI project</summary>
/// <copyright>(c) 2016 MojoTouch</copyright>
/// <author>Ilya Rovensky</author>
#endregion

using System;
using System.Collections.Generic;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Input;

namespace WpfInterface
{
    public partial class ListPopUp : PopUp 
    {
        internal struct ListData
        {
            internal string Message;
            internal List<string> Slots;

            internal int ButtonCount;
            internal string NegativeButtonTitle;
            internal string PositiveButtonTitle;
        }

        public ListPopUp()
        {
            InitializeComponent();
        }

        private List<string> _items;

        internal ListPopUp(ListData listData) : this()
        {
            CaptionBlock.Text = listData.Message;
            _items = listData.Slots;
            SlotBox.ItemsSource = _items;

            NegativeButton.Content = listData.NegativeButtonTitle;
            PositiveButton.Content = listData.PositiveButtonTitle;

            switch (listData.ButtonCount)
            {
                case 0:
                    NegativeButton.Visibility = Visibility.Hidden;
                    PositiveButton.Visibility = Visibility.Hidden;
                    break;
                case 1:
                    PositiveButton.Visibility = Visibility.Hidden;
                    break;
            }
        }

        private void Button_Click(object sender, RoutedEventArgs e)
        {
            SetResultFromSenderTag((FrameworkElement)sender);
        }

        private void RadioButton_Click(object sender, RoutedEventArgs e)
        {
            ListBoxItem item = (ListBoxItem)((ContentPresenter)((RadioButton)sender).TemplatedParent).TemplatedParent;
            int index = SlotBox.ItemContainerGenerator.IndexFromContainer(item);

            if (index > -1)
            {
                Result = (MenuAction)(index + (int)MenuAction.ListSlot1);
                DialogResult = true;
            }
        }
    }
}
